@@ -1,15 +1,10 @@
 from . import chars, edit_tokens, parsed, tokenized
-from ....dependencies import DependentSet
-
-prefix = "wikitext.revision"
 
 
-class BaseRevision(DependentSet):
-
+class Revision(parsed.Revision, chars.Revision, tokenized.Revision):
     def __init__(self, name, revision_datasources):
-        super().__init__(name)
-        self.datasources = revision_datasources
-
+        # Initializes all of the Revision datasources
+        super().__init__(name, revision_datasources)
         if hasattr(self.datasources, "parent"):
             self.parent = Revision(
                 name + ".parent",
@@ -31,17 +26,5 @@ class BaseRevision(DependentSet):
             """
 
 
-class Revision(parsed.Revision, chars.Revision, tokenized.Revision,
-               BaseRevision):
-    pass
-
-
-class BaseDiff(DependentSet):
-
-    def __init__(self, name, diff_datasources, *args, **kwargs):
-        super().__init__(name)
-        self.datasources = diff_datasources
-
-
-class Diff(chars.Diff, edit_tokens.Diff, tokenized.Diff, BaseDiff):
+class Diff(chars.Diff, edit_tokens.Diff, tokenized.Diff):
     pass
